import os

basedir = os.path.abspath(os.path.dirname(__file__))


class Config:
    SECURITY_PASSWORD_HASH = 'pbkdf2_sha512'
    SECURITY_REGISTERABLE = True
    SECURITY_CHANGEABLE = True
    SECURITY_RECOVERABLE = True
    SECURITY_PASSWORD_SALT = os.environ.get('SECURITY_PASSWORD_SALT') or 'SOME SECRET STRING'
    SECRET_KEY = os.environ.get('SECRET_KEY') or 'SOME SECRET STRING'
    SECURITY_EMAIL_SENDER = 'no-reply@lusiardi.de'
    SQLALCHEMY_TRACK_MODIFICATIONS = False
    MAIL_SERVER = 'mail.nerd2nerd.org'
    MAIL_PORT = 25
    MAIL_USE_TLS = True
    MAIL_USE_SSL = False
    MAIL_USERNAME = os.environ.get('MAIL_USERNAME')
    MAIL_PASSWORD = os.environ.get('MAIL_PASSWORD')
    ADMIN_MAIL = 'joachim@lusiardi.de'
    TANKERKOENIG_API_KEY = os.environ.get('TANKERKOENIG_API_KEY')
    DEBUG = False

    @staticmethod
    def init_app(app):
        pass


class DevelopmentConfig(Config):
    SECURITY_SEND_REGISTER_EMAIL = False
    DEBUG = True
    SQLALCHEMY_DATABASE_URI = 'sqlite:////data/data.sqlite'


class TestingConfig(Config):
    SECURITY_SEND_REGISTER_EMAIL = False
    DEBUG = True
    SQLALCHEMY_DATABASE_URI = 'mysql+pymysql://root:{p}@{h}/pitstops'.format(p=os.environ.get('MYSQL_PASSWORD'),
                                                                             h=os.environ.get('MYSQL_HOST'))


class ProductionConfig(Config):
    SQLALCHEMY_DATABASE_URI = 'mysql+pymysql://pitstops:{h}@localhost/pitstops'.format(
        h=os.environ.get('MYSQL_PASSWORD'))


config = {
    'development': DevelopmentConfig,
    'testing': TestingConfig,
    'production': ProductionConfig,
    'default': DevelopmentConfig
}
